@@ -6,7 +6,8 @@ from django.db import models, connection, transaction, router, connections
 from django.db.models.query import QuerySet
 from django.db.models.deletion import Collector
 
-from m3.core.json import json_encode
+from m3 import json_encode, RelatedError
+
 
 def safe_delete(model):
     """
@@ -14,62 +15,74 @@ def safe_delete(model):
     В случае, если удаление не удалось по причине нарушения целостности,
     то возвращается false. Иначе, true
     к тому же функция пересчитывает MPTT индексы дерева
-    т.к. стандартный пересчет запускается при вызове model_instance.delete() 
+    т.к. стандартный пересчет запускается при вызове model_instance.delete()
     """
     models.signals.pre_delete.send(sender=model.__class__, instance=model)
     try:
-        cursor = connection.cursor() #@UndefinedVariable
-        sql = "DELETE FROM %s WHERE id = %s" % (connection.ops.quote_name(model._meta.db_table), model.id) #@UndefinedVariable
+        cursor = connection.cursor()
+        sql = "DELETE FROM %s WHERE id = %s" % (
+            connection.ops.quote_name(model._meta.db_table), model.id)
         cursor.execute(sql)
         transaction.commit_unless_managed()
     except Exception, e:
-        # Встроенный в Django IntegrityError не генерируется. Кидаются исключения 
-        # специфичные для каждого драйвера БД. Но по спецификации PEP 249 все они
-        # называются IntegrityError
+        # Встроенный в Django IntegrityError не генерируется.
+        # Кидаются исключения, специфичные для каждого драйвера БД.
+        # Но по спецификации PEP 249 все они называются IntegrityError
         if e.__class__.__name__ == 'IntegrityError':
             return False
         raise
 
-    #добавим пересчет mptt дерева (т.к. стандартный пересчет вешается на метод self.delete()
-    if hasattr(model, '_tree_manager') and callable(getattr(model._tree_manager, '_close_gap', None)):
-        #это видимо mptt моедль
+    # добавим пересчет mptt дерева
+    # (т.к. стандартный пересчет вешается на метод self.delete()
+    if hasattr(model, '_tree_manager') and callable(
+            getattr(model._tree_manager, '_close_gap', None)):
+        #это, видимо, mptt модель
         opts = model._meta
-        tree_width = (getattr(model, opts.right_attr) -
-                      getattr(model, opts.left_attr) + 1)
-        target_right = getattr(model, opts.right_attr)
-        tree_id = getattr(model, opts.tree_id_attr)
-        model._tree_manager._close_gap(tree_width, target_right, tree_id)        
-    
+        r = getattr(model, getattr(opts, 'right_attr', 'rght'))
+        l = getattr(model, getattr(opts, 'left_attr', 'lft'))
+        t = getattr(model, getattr(opts, 'tree_id_attr', 'tree_id'))
+        model._tree_manager._close_gap(r - l + 1, r, t)
+
     models.signals.post_delete.send(sender=model.__class__, instance=model)
     return True
 
+
 def queryset_limiter(queryset, start=0, limit=0):
     """
-    "Вырезает" из QuerySet'a записи начиная с позиции start до записи start+limit.
+    "Вырезает" из QuerySet'a записи начиная с позиции start
+    до записи start+limit.
     Возвращает (rows, total, ), где
     rows -  QuerySet с вырезанными записями
     total - общее кол-во записей в queryset'e
     """
-    
-    assert (isinstance(queryset, QuerySet) or getattr(queryset, '__iter__')), \
-    'queryset must be either instance of django.db.models.query.QuerySet or iterable' 
-    
+
+    assert (isinstance(queryset, QuerySet) or getattr(queryset, '__iter__')), (
+        'queryset must be either instance of '
+        'django.db.models.query.QuerySet or iterable'
+    )
+
     if start < 0:
         start = 0
     if limit < 0:
         limit = 0
-    total = queryset.count() if isinstance(queryset, QuerySet) else len(queryset)
+    total = (
+        queryset.count()
+        if isinstance(queryset, QuerySet)
+        else len(queryset)
+    )
     rows = queryset[start:start+limit]
     return rows, total
 
+
 class BaseEnumerate(object):
     """
     Базовый класс для создания перечислений.
     """
-    # В словаре values описываются перечисляемые константы и их человеческое название
+    # В словаре values описываются перечисляемые константы
+    # и их человеческое название
     # Например: {STATE1: u'Состояние 1', CLOSED: u'Закрыто'}
     values = {}
-    
+
     @classmethod
     def get_choices(cls):
         """
@@ -77,7 +90,7 @@ class BaseEnumerate(object):
         в ArrayStore и DataStore ExtJS
         """
         return cls.values.items()
-    
+
     get_items = get_choices
 
     @classmethod
@@ -91,14 +104,15 @@ class BaseEnumerate(object):
 
         if not name:
             raise ValueError("'name' must not be empty")
-        
+
         return cls.__dict__[name]
 
 
 class BaseObjectModel(models.Model):
     """
-    Базовая модель для объектов системы. 
-    Сюда будут добавляться общие свойства и методы, которые могут быть перекрыты в дальнейшем
+    Базовая модель для объектов системы.
+    Сюда будут добавляться общие свойства и методы,
+    которые могут быть перекрыты в дальнейшем
     """
     @json_encode
     def display(self):
@@ -117,7 +131,7 @@ class BaseObjectModel(models.Model):
             return u'{%s: %s}' % (self.pk, name)
         else:
             return u'{%s}' % self.pk
-    
+
     @classmethod
     def get_verbose_name(cls):
         return cls._meta.verbose_name
@@ -125,91 +139,115 @@ class BaseObjectModel(models.Model):
     def safe_delete(self):
         """
         Функция выполняющая "безопасное" удаление записи из БД.
-        В случае, если запись не удалось удалисть по причине нарушения
+        В случае, если запись не удалось удалить по причине нарушения
         целостности, возвращается False, иначе True.
         """
-        return safe_delete(self)
+        if not safe_delete(self):
+            raise RelatedError(
+                u"Объект не может быть удален! Возможно на него есть ссылки.")
 
     def get_related_objects(self, using=None):
         """
-        Возвращает структуру содержащую классы моделей, первичные ключи и экземпляры записей,
-        зависящие от текущей записи. Возвращаемая структура имеет вид:
-        [(КлассМодели1, {id1: ЭкземплярМодели1cID1, id2: ЭкземплярМодели1cID2, ...} ),
-         (КлассМодели2, {id1: ЭкземплярМодели2cID1, id2: ЭкземплярМодели2cID2, ...} },
-         ...]
+        Возвращает структуру содержащую классы моделей,
+        первичные ключи и экземпляры записей, зависящие от текущей записи.
+        Возвращаемая структура имеет вид:
+        [(КлассМодели1,
+            {id1: ЭкземплярМодели1cID1, id2: ЭкземплярМодели1cID2, ...}),
+         (КлассМодели2,
+            {id1: ЭкземплярМодели2cID1, id2: ЭкземплярМодели2cID2, ...} },
+        ...]
         @deprecated: Вытаскивает много данных. Сервер может зависнуть!
         """
         using = using or router.db_for_write(self.__class__, instance=self)
         collector = Collector(using=using)
         collector.collect([self])
         return collector.data.items()
-    
+
     def delete_related(self, affected=None, using=None):
         """
-        Стандартное каскадное удаление объектов в django, дополненное проверкой на 
-        удаляемые классы моделей affected. По умолчанию affected содержит пустой 
-        список - это ограничивает удаляемые модели только текущим классом.
+        Стандартное каскадное удаление объектов в django,
+        дополненное проверкой на удаляемые классы моделей affected.
+        По умолчанию affected содержит пустой список
+        - это ограничивает удаляемые модели только текущим классом.
         К перечисленным в affected классам текущий добавляется автоматически.
         Если удаление не удалось выполнить, возвращает False, иначе True.
-        Пример: Model1.objects.get(id=1).delete_related(affected=[Model2, Model3])
+        Пример:
+            Model1.objects.get(id=1).delete_related(affected=[Model2, Model3])
         """
         # Кописаст из django.db.models.Model delete()
         using = using or router.db_for_write(self.__class__, instance=self)
-        assert self._get_pk_val() is not None, "%s object can't be deleted because its %s attribute is set to None." % (self._meta.object_name, self._meta.pk.attname)
+        assert self._get_pk_val() is not None, (
+            "%s object can't be deleted because its "
+            "%s attribute is set to None."
+        ) % (
+            self._meta.object_name,
+            self._meta.pk.attname
+        )
 
         collector = Collector(using=using)
         collector.collect([self])
         # cut
-        
+
         affected = affected or []
-        assert isinstance(affected, list), 'Affected models must be the list type'
+        assert isinstance(affected, list), (
+            'Affected models must be the list type')
         affected.append(self.__class__)
-        
+
         for model in collector.data.keys():
             if model not in affected:
                 return False
-        
+
         collector.delete()
         return True
 
     class Meta:
         abstract = True
 
+
 ##############################################################
 # По мотивам https://coderanger.net/2011/01/select-for-update/
-#
 class ForUpdateQuerySet(QuerySet):
     def for_update(self):
         if 'sqlite' in connections[self.db].settings_dict['ENGINE'].lower():
             # Noop on SQLite since it doesn't support FOR UPDATE
             return self
         sql, params = self.query.get_compiler(self.db).as_sql()
-        return self.model._default_manager.raw(sql.rstrip() + ' FOR UPDATE', params)
+        return self.model._default_manager.raw(
+            sql.rstrip() + ' FOR UPDATE', params)
+
 
 class ForUpdateManager(models.Manager):
     def get_query_set(self):
         return ForUpdateQuerySet(self.model, using=self._db)
-#
 ##############################################################
 
+
 class ConcurrentEditError(Exception):
-    """Исключение возникающее при попытке сохранения записи, которая была изменена после ее чтения."""
+    """
+    Исключение возникающее при попытке сохранения записи,
+    которая была изменена после ее чтения.
+    """
     pass
 
+
 class BaseObjectModelWVersion(BaseObjectModel):
     """
-    Базовый класс для версионных записей. Нужен для реализации оптимистичной обработки блокировки
+    Базовый класс для версионных записей.
+    Нужен для реализации оптимистичной обработки блокировки
     """
-    
+
     objects = ForUpdateManager()
-    
+
     version = models.IntegerField(u'Версия записи', default=0)
-    
+
     def do_lock(self):
         if self.id:
             # блокируем запись с нашей версией от изменения
-            q = self.__class__.objects.filter(id = self.id, version = self.version).for_update()
-            # если удачно блокировали, то можем делать с ней что угодно в рамках транзакции
+            q = self.__class__.objects.filter(
+                id=self.id, version=self.version
+            ).for_update()
+            # если удачно блокировали,
+            # то можем делать с ней что угодно в рамках транзакции
             if len(list(q)) == 1:
                 return True
             else:
@@ -221,28 +259,34 @@ class BaseObjectModelWVersion(BaseObjectModel):
     def save(self, *a, **k):
         """
         При каждом сохранении номер версии увеличивается.
-        Это нужно чтобы проверять, была ли модифицирована запись после последнего получения
+        Это нужно чтобы проверять, была ли модифицирована запись
+        после последнего получения
         """
         if self.id:
             self.version += 1
         super(BaseObjectModelWVersion, self).save()
-            
+
     class Meta:
         abstract = True
 
+
 class ObjectState(BaseEnumerate):
     """
     Состояние объекта
     Используется для определения логики использования записи:
     - если запись "Действует", значит нет ограничений на ее использование
-    - если запись "Закрыта", значит ее нельзя использовать в новых документах, но можно выводить в отчетах и уже существующих данных
-    - если запись "Черновик", значит ее нельзя использовать в логике приложения и в отчетах. По сути, это означает что запись введена не полностью и не утверждена
+    - если запись "Закрыта", значит ее нельзя использовать в новых документах,
+      но можно выводить в отчетах и уже существующих данных
+    - если запись "Черновик", значит ее нельзя использовать в логике приложения
+      и в отчетах. По сути, это означает,
+      что запись введена не полностью и не утверждена
     """
     VALID = 0
     CLOSED = 1
     DRAFT = 2
     values = {VALID: u'Действует', CLOSED: u'Закрыта', DRAFT: u'Черновик'}
-    
+
+
 class ObjectManager(models.Manager):
     """
     Менеджер запросов к записям справочника
@@ -253,8 +297,8 @@ class ObjectManager(models.Manager):
         Для прикладного переопределения состояний, выбираемых по-умолчанию
         """
         return [ObjectState.VALID]
-    
-    def __init__(self, date = None, state = None, *a, **kw):
+
+    def __init__(self, date=None, state=None, *a, **kw):
         super(ObjectManager, self).__init__(*a, **kw)
         self.query_on_date = date
         if state:
@@ -264,25 +308,49 @@ class ObjectManager(models.Manager):
                 self.query_state = [state]
         else:
             self.query_state = self.get_default_state()
-        
+
     def get_query_set(self):
-        # если указывали дату, то отфильтруем на дату, иначе только по состоянию
+        # если указывали дату,
+        # то отфильтруем на дату, иначе только по состоянию
         if self.query_on_date:
-            return super(ObjectManager, self).get_query_set().filter(begin__lte = self.query_on_date, end__gt = self.query_on_date, state__in = self.query_state)
+            return super(ObjectManager, self).get_query_set().filter(
+                begin__lte=self.query_on_date,
+                end__gt=self.query_on_date,
+                state__in=self.query_state
+            )
         else:
-            return super(ObjectManager, self).get_query_set().filter(state__in = self.query_state)
+            return super(ObjectManager, self).get_query_set().filter(
+                state__in=self.query_state
+            )
+
 
 class BaseObjectModelWState(BaseObjectModel):
     """
     Базовый класс для всех моделей состоянием и периодом действия
     """
-    
-    state = models.SmallIntegerField(u'Состояние', choices = ObjectState.get_choices(), default = ObjectState.DRAFT)
-    begin = models.DateTimeField(u'Начало действия', null = True, blank = True, db_index = True, default = datetime.date.min)
-    end = models.DateTimeField(u'Окончание действия', null = True, blank = True, db_index = True, default = datetime.date.max)
-    
+
+    state = models.SmallIntegerField(
+        u'Состояние',
+        choices=ObjectState.get_choices(),
+        default=ObjectState.DRAFT
+    )
+    begin = models.DateTimeField(
+        u'Начало действия',
+        null=True,
+        blank=True,
+        db_index=True,
+        default=datetime.date.min
+    )
+    end = models.DateTimeField(
+        u'Окончание действия',
+        null=True,
+        blank=True,
+        db_index=True,
+        default=datetime.date.max
+    )
+
     @classmethod
-    def get_objects_on_date(cls, date = None):
+    def get_objects_on_date(cls, date=None):
         """
         Получает менеджер с параметрами.
         Можно писать так: Model.objects_on_date(datetime.today).filter....
@@ -290,15 +358,8 @@ class BaseObjectModelWState(BaseObjectModel):
         manager = ObjectManager(date=date)
         manager.model = cls
         return manager
-    
+
     objects_on_date = get_objects_on_date
-    
+
     class Meta:
         abstract = True
-        
-#class BaseRecordModel(BaseObjectModelWVersion, BaseObjectModelWState):
-#    """
-#    Базовый класс записей справочников с состоянием и версионностью
-#    """
-#    class Meta:
-#        abstract = True
